/* shotwell-transitions.c generated by valac 0.56.19, the Vala compiler
 * generated from shotwell-transitions.vala, do not modify */

/*
* Copyright (c) 2011-2013 Yorba Foundation
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the
* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
* Boston, MA 02110-1301 USA
*/

#include <glib-object.h>
#include "io.elementary.photos.h"
#include <glib.h>
#include <gio/gio.h>
#include <gtk/gtk.h>
#include "pantheon-photos-transitions.h"
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <config.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

#define TYPE_SHOTWELL_TRANSITIONS (shotwell_transitions_get_type ())
#define SHOTWELL_TRANSITIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SHOTWELL_TRANSITIONS, ShotwellTransitions))
#define SHOTWELL_TRANSITIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SHOTWELL_TRANSITIONS, ShotwellTransitionsClass))
#define IS_SHOTWELL_TRANSITIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SHOTWELL_TRANSITIONS))
#define IS_SHOTWELL_TRANSITIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SHOTWELL_TRANSITIONS))
#define SHOTWELL_TRANSITIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SHOTWELL_TRANSITIONS, ShotwellTransitionsClass))

typedef struct _ShotwellTransitions ShotwellTransitions;
typedef struct _ShotwellTransitionsClass ShotwellTransitionsClass;
typedef struct _ShotwellTransitionsPrivate ShotwellTransitionsPrivate;
enum  {
	SHOTWELL_TRANSITIONS_0_PROPERTY,
	SHOTWELL_TRANSITIONS_NUM_PROPERTIES
};
static GParamSpec* shotwell_transitions_properties[SHOTWELL_TRANSITIONS_NUM_PROPERTIES];

#define TYPE_FADE_EFFECT_DESCRIPTOR (fade_effect_descriptor_get_type ())
#define FADE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FADE_EFFECT_DESCRIPTOR, FadeEffectDescriptor))
#define FADE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FADE_EFFECT_DESCRIPTOR, FadeEffectDescriptorClass))
#define IS_FADE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FADE_EFFECT_DESCRIPTOR))
#define IS_FADE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FADE_EFFECT_DESCRIPTOR))
#define FADE_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FADE_EFFECT_DESCRIPTOR, FadeEffectDescriptorClass))

typedef struct _FadeEffectDescriptor FadeEffectDescriptor;
typedef struct _FadeEffectDescriptorClass FadeEffectDescriptorClass;

#define TYPE_SLIDE_EFFECT_DESCRIPTOR (slide_effect_descriptor_get_type ())
#define SLIDE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SLIDE_EFFECT_DESCRIPTOR, SlideEffectDescriptor))
#define SLIDE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SLIDE_EFFECT_DESCRIPTOR, SlideEffectDescriptorClass))
#define IS_SLIDE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SLIDE_EFFECT_DESCRIPTOR))
#define IS_SLIDE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SLIDE_EFFECT_DESCRIPTOR))
#define SLIDE_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SLIDE_EFFECT_DESCRIPTOR, SlideEffectDescriptorClass))

typedef struct _SlideEffectDescriptor SlideEffectDescriptor;
typedef struct _SlideEffectDescriptorClass SlideEffectDescriptorClass;

#define TYPE_CRUMBLE_EFFECT_DESCRIPTOR (crumble_effect_descriptor_get_type ())
#define CRUMBLE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CRUMBLE_EFFECT_DESCRIPTOR, CrumbleEffectDescriptor))
#define CRUMBLE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CRUMBLE_EFFECT_DESCRIPTOR, CrumbleEffectDescriptorClass))
#define IS_CRUMBLE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CRUMBLE_EFFECT_DESCRIPTOR))
#define IS_CRUMBLE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CRUMBLE_EFFECT_DESCRIPTOR))
#define CRUMBLE_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CRUMBLE_EFFECT_DESCRIPTOR, CrumbleEffectDescriptorClass))

typedef struct _CrumbleEffectDescriptor CrumbleEffectDescriptor;
typedef struct _CrumbleEffectDescriptorClass CrumbleEffectDescriptorClass;

#define TYPE_BLINDS_EFFECT_DESCRIPTOR (blinds_effect_descriptor_get_type ())
#define BLINDS_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BLINDS_EFFECT_DESCRIPTOR, BlindsEffectDescriptor))
#define BLINDS_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BLINDS_EFFECT_DESCRIPTOR, BlindsEffectDescriptorClass))
#define IS_BLINDS_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BLINDS_EFFECT_DESCRIPTOR))
#define IS_BLINDS_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BLINDS_EFFECT_DESCRIPTOR))
#define BLINDS_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BLINDS_EFFECT_DESCRIPTOR, BlindsEffectDescriptorClass))

typedef struct _BlindsEffectDescriptor BlindsEffectDescriptor;
typedef struct _BlindsEffectDescriptorClass BlindsEffectDescriptorClass;

#define TYPE_CIRCLE_EFFECT_DESCRIPTOR (circle_effect_descriptor_get_type ())
#define CIRCLE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CIRCLE_EFFECT_DESCRIPTOR, CircleEffectDescriptor))
#define CIRCLE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CIRCLE_EFFECT_DESCRIPTOR, CircleEffectDescriptorClass))
#define IS_CIRCLE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CIRCLE_EFFECT_DESCRIPTOR))
#define IS_CIRCLE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CIRCLE_EFFECT_DESCRIPTOR))
#define CIRCLE_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CIRCLE_EFFECT_DESCRIPTOR, CircleEffectDescriptorClass))

typedef struct _CircleEffectDescriptor CircleEffectDescriptor;
typedef struct _CircleEffectDescriptorClass CircleEffectDescriptorClass;

#define TYPE_CIRCLES_EFFECT_DESCRIPTOR (circles_effect_descriptor_get_type ())
#define CIRCLES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CIRCLES_EFFECT_DESCRIPTOR, CirclesEffectDescriptor))
#define CIRCLES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CIRCLES_EFFECT_DESCRIPTOR, CirclesEffectDescriptorClass))
#define IS_CIRCLES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CIRCLES_EFFECT_DESCRIPTOR))
#define IS_CIRCLES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CIRCLES_EFFECT_DESCRIPTOR))
#define CIRCLES_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CIRCLES_EFFECT_DESCRIPTOR, CirclesEffectDescriptorClass))

typedef struct _CirclesEffectDescriptor CirclesEffectDescriptor;
typedef struct _CirclesEffectDescriptorClass CirclesEffectDescriptorClass;

#define TYPE_CLOCK_EFFECT_DESCRIPTOR (clock_effect_descriptor_get_type ())
#define CLOCK_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CLOCK_EFFECT_DESCRIPTOR, ClockEffectDescriptor))
#define CLOCK_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CLOCK_EFFECT_DESCRIPTOR, ClockEffectDescriptorClass))
#define IS_CLOCK_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CLOCK_EFFECT_DESCRIPTOR))
#define IS_CLOCK_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CLOCK_EFFECT_DESCRIPTOR))
#define CLOCK_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CLOCK_EFFECT_DESCRIPTOR, ClockEffectDescriptorClass))

typedef struct _ClockEffectDescriptor ClockEffectDescriptor;
typedef struct _ClockEffectDescriptorClass ClockEffectDescriptorClass;

#define TYPE_SQUARES_EFFECT_DESCRIPTOR (squares_effect_descriptor_get_type ())
#define SQUARES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SQUARES_EFFECT_DESCRIPTOR, SquaresEffectDescriptor))
#define SQUARES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SQUARES_EFFECT_DESCRIPTOR, SquaresEffectDescriptorClass))
#define IS_SQUARES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SQUARES_EFFECT_DESCRIPTOR))
#define IS_SQUARES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SQUARES_EFFECT_DESCRIPTOR))
#define SQUARES_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SQUARES_EFFECT_DESCRIPTOR, SquaresEffectDescriptorClass))

typedef struct _SquaresEffectDescriptor SquaresEffectDescriptor;
typedef struct _SquaresEffectDescriptorClass SquaresEffectDescriptorClass;

#define TYPE_CHESS_EFFECT_DESCRIPTOR (chess_effect_descriptor_get_type ())
#define CHESS_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHESS_EFFECT_DESCRIPTOR, ChessEffectDescriptor))
#define CHESS_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHESS_EFFECT_DESCRIPTOR, ChessEffectDescriptorClass))
#define IS_CHESS_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHESS_EFFECT_DESCRIPTOR))
#define IS_CHESS_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHESS_EFFECT_DESCRIPTOR))
#define CHESS_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHESS_EFFECT_DESCRIPTOR, ChessEffectDescriptorClass))

typedef struct _ChessEffectDescriptor ChessEffectDescriptor;
typedef struct _ChessEffectDescriptorClass ChessEffectDescriptorClass;

#define TYPE_STRIPES_EFFECT_DESCRIPTOR (stripes_effect_descriptor_get_type ())
#define STRIPES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_STRIPES_EFFECT_DESCRIPTOR, StripesEffectDescriptor))
#define STRIPES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_STRIPES_EFFECT_DESCRIPTOR, StripesEffectDescriptorClass))
#define IS_STRIPES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_STRIPES_EFFECT_DESCRIPTOR))
#define IS_STRIPES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_STRIPES_EFFECT_DESCRIPTOR))
#define STRIPES_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_STRIPES_EFFECT_DESCRIPTOR, StripesEffectDescriptorClass))

typedef struct _StripesEffectDescriptor StripesEffectDescriptor;
typedef struct _StripesEffectDescriptorClass StripesEffectDescriptorClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
enum  {
	SHOTWELL_TRANSITION_DESCRIPTOR_0_PROPERTY,
	SHOTWELL_TRANSITION_DESCRIPTOR_NUM_PROPERTIES
};
static GParamSpec* shotwell_transition_descriptor_properties[SHOTWELL_TRANSITION_DESCRIPTOR_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

struct _ShotwellTransitions {
	GObject parent_instance;
	ShotwellTransitionsPrivate * priv;
};

struct _ShotwellTransitionsClass {
	GObjectClass parent_class;
};

struct _ShotwellTransitionsPrivate {
	SpitPluggable** pluggables;
	gint pluggables_length1;
	gint _pluggables_size_;
};

struct _ShotwellTransitionDescriptorPrivate {
	GIcon* icon;
};

static gint ShotwellTransitions_private_offset;
static gpointer shotwell_transitions_parent_class = NULL;
static SpitModuleIface * shotwell_transitions_spit_module_parent_iface = NULL;
static gint ShotwellTransitionDescriptor_private_offset;
static gpointer shotwell_transition_descriptor_parent_class = NULL;
static SpitPluggableIface * shotwell_transition_descriptor_spit_pluggable_parent_iface = NULL;
static SpitTransitionsDescriptorIface * shotwell_transition_descriptor_spit_transitions_descriptor_parent_iface = NULL;

VALA_EXTERN GType shotwell_transitions_get_type (void) G_GNUC_CONST ;
VALA_EXTERN ShotwellTransitions* shotwell_transitions_new (GFile* module_file);
VALA_EXTERN ShotwellTransitions* shotwell_transitions_construct (GType object_type,
                                                     GFile* module_file);
VALA_EXTERN FadeEffectDescriptor* fade_effect_descriptor_new (GFile* resource_directory);
VALA_EXTERN FadeEffectDescriptor* fade_effect_descriptor_construct (GType object_type,
                                                        GFile* resource_directory);
VALA_EXTERN GType fade_effect_descriptor_get_type (void) G_GNUC_CONST ;
static void _vala_array_add1 (SpitPluggable** * array,
                       gint* length,
                       gint* size,
                       SpitPluggable* value);
VALA_EXTERN SlideEffectDescriptor* slide_effect_descriptor_new (GFile* resource_directory);
VALA_EXTERN SlideEffectDescriptor* slide_effect_descriptor_construct (GType object_type,
                                                          GFile* resource_directory);
VALA_EXTERN GType slide_effect_descriptor_get_type (void) G_GNUC_CONST ;
static void _vala_array_add2 (SpitPluggable** * array,
                       gint* length,
                       gint* size,
                       SpitPluggable* value);
VALA_EXTERN CrumbleEffectDescriptor* crumble_effect_descriptor_new (GFile* resource_directory);
VALA_EXTERN CrumbleEffectDescriptor* crumble_effect_descriptor_construct (GType object_type,
                                                              GFile* resource_directory);
VALA_EXTERN GType crumble_effect_descriptor_get_type (void) G_GNUC_CONST ;
static void _vala_array_add3 (SpitPluggable** * array,
                       gint* length,
                       gint* size,
                       SpitPluggable* value);
VALA_EXTERN BlindsEffectDescriptor* blinds_effect_descriptor_new (GFile* resource_directory);
VALA_EXTERN BlindsEffectDescriptor* blinds_effect_descriptor_construct (GType object_type,
                                                            GFile* resource_directory);
VALA_EXTERN GType blinds_effect_descriptor_get_type (void) G_GNUC_CONST ;
static void _vala_array_add4 (SpitPluggable** * array,
                       gint* length,
                       gint* size,
                       SpitPluggable* value);
VALA_EXTERN CircleEffectDescriptor* circle_effect_descriptor_new (GFile* resource_directory);
VALA_EXTERN CircleEffectDescriptor* circle_effect_descriptor_construct (GType object_type,
                                                            GFile* resource_directory);
VALA_EXTERN GType circle_effect_descriptor_get_type (void) G_GNUC_CONST ;
static void _vala_array_add5 (SpitPluggable** * array,
                       gint* length,
                       gint* size,
                       SpitPluggable* value);
VALA_EXTERN CirclesEffectDescriptor* circles_effect_descriptor_new (GFile* resource_directory);
VALA_EXTERN CirclesEffectDescriptor* circles_effect_descriptor_construct (GType object_type,
                                                              GFile* resource_directory);
VALA_EXTERN GType circles_effect_descriptor_get_type (void) G_GNUC_CONST ;
static void _vala_array_add6 (SpitPluggable** * array,
                       gint* length,
                       gint* size,
                       SpitPluggable* value);
VALA_EXTERN ClockEffectDescriptor* clock_effect_descriptor_new (GFile* resource_directory);
VALA_EXTERN ClockEffectDescriptor* clock_effect_descriptor_construct (GType object_type,
                                                          GFile* resource_directory);
VALA_EXTERN GType clock_effect_descriptor_get_type (void) G_GNUC_CONST ;
static void _vala_array_add7 (SpitPluggable** * array,
                       gint* length,
                       gint* size,
                       SpitPluggable* value);
VALA_EXTERN SquaresEffectDescriptor* squares_effect_descriptor_new (GFile* resource_directory);
VALA_EXTERN SquaresEffectDescriptor* squares_effect_descriptor_construct (GType object_type,
                                                              GFile* resource_directory);
VALA_EXTERN GType squares_effect_descriptor_get_type (void) G_GNUC_CONST ;
static void _vala_array_add8 (SpitPluggable** * array,
                       gint* length,
                       gint* size,
                       SpitPluggable* value);
VALA_EXTERN ChessEffectDescriptor* chess_effect_descriptor_new (GFile* resource_directory);
VALA_EXTERN ChessEffectDescriptor* chess_effect_descriptor_construct (GType object_type,
                                                          GFile* resource_directory);
VALA_EXTERN GType chess_effect_descriptor_get_type (void) G_GNUC_CONST ;
static void _vala_array_add9 (SpitPluggable** * array,
                       gint* length,
                       gint* size,
                       SpitPluggable* value);
VALA_EXTERN StripesEffectDescriptor* stripes_effect_descriptor_new (GFile* resource_directory);
VALA_EXTERN StripesEffectDescriptor* stripes_effect_descriptor_construct (GType object_type,
                                                              GFile* resource_directory);
VALA_EXTERN GType stripes_effect_descriptor_get_type (void) G_GNUC_CONST ;
static void _vala_array_add10 (SpitPluggable** * array,
                        gint* length,
                        gint* size,
                        SpitPluggable* value);
static const gchar* shotwell_transitions_real_get_module_name (SpitModule* base);
static const gchar* shotwell_transitions_real_get_version (SpitModule* base);
static const gchar* shotwell_transitions_real_get_id (SpitModule* base);
static SpitPluggable** shotwell_transitions_real_get_pluggables (SpitModule* base,
                                                          gint* result_length1);
static void shotwell_transitions_finalize (GObject * obj);
static GType shotwell_transitions_get_type_once (void);
static gint shotwell_transition_descriptor_real_get_pluggable_interface (SpitPluggable* base,
                                                                  gint min_host_interface,
                                                                  gint max_host_interface);
static const gchar* shotwell_transition_descriptor_real_get_id (ShotwellTransitionDescriptor* self);
static const gchar* shotwell_transition_descriptor_real_get_pluggable_name (ShotwellTransitionDescriptor* self);
static void shotwell_transition_descriptor_real_get_info (SpitPluggable* base,
                                                   SpitPluggableInfo* info);
static void shotwell_transition_descriptor_real_activation (SpitPluggable* base,
                                                     gboolean enabled);
static SpitTransitionsEffect* shotwell_transition_descriptor_real_create (ShotwellTransitionDescriptor* self,
                                                                   SpitHostInterface* host);
static void shotwell_transition_descriptor_finalize (GObject * obj);
static GType shotwell_transition_descriptor_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
shotwell_transitions_get_instance_private (ShotwellTransitions* self)
{
	return G_STRUCT_MEMBER_P (self, ShotwellTransitions_private_offset);
}

static void
_vala_array_add1 (SpitPluggable** * array,
                  gint* length,
                  gint* size,
                  SpitPluggable* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add2 (SpitPluggable** * array,
                  gint* length,
                  gint* size,
                  SpitPluggable* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add3 (SpitPluggable** * array,
                  gint* length,
                  gint* size,
                  SpitPluggable* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add4 (SpitPluggable** * array,
                  gint* length,
                  gint* size,
                  SpitPluggable* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add5 (SpitPluggable** * array,
                  gint* length,
                  gint* size,
                  SpitPluggable* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add6 (SpitPluggable** * array,
                  gint* length,
                  gint* size,
                  SpitPluggable* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add7 (SpitPluggable** * array,
                  gint* length,
                  gint* size,
                  SpitPluggable* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add8 (SpitPluggable** * array,
                  gint* length,
                  gint* size,
                  SpitPluggable* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add9 (SpitPluggable** * array,
                  gint* length,
                  gint* size,
                  SpitPluggable* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add10 (SpitPluggable** * array,
                   gint* length,
                   gint* size,
                   SpitPluggable* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

ShotwellTransitions*
shotwell_transitions_construct (GType object_type,
                                GFile* module_file)
{
	ShotwellTransitions * self = NULL;
	GtkIconTheme* _tmp0_;
	GFile* resource_directory = NULL;
	GFile* _tmp1_;
	FadeEffectDescriptor* _tmp2_;
	SlideEffectDescriptor* _tmp3_;
	CrumbleEffectDescriptor* _tmp4_;
	BlindsEffectDescriptor* _tmp5_;
	CircleEffectDescriptor* _tmp6_;
	CirclesEffectDescriptor* _tmp7_;
	ClockEffectDescriptor* _tmp8_;
	SquaresEffectDescriptor* _tmp9_;
	ChessEffectDescriptor* _tmp10_;
	StripesEffectDescriptor* _tmp11_;
	g_return_val_if_fail (module_file != NULL, NULL);
	self = (ShotwellTransitions*) g_object_new (object_type, NULL);
	_tmp0_ = gtk_icon_theme_get_default ();
	gtk_icon_theme_add_resource_path (_tmp0_, "/io/elementary/photos/plugins/transitions/icons");
	_tmp1_ = g_file_get_parent (module_file);
	resource_directory = _tmp1_;
	_tmp2_ = fade_effect_descriptor_new (resource_directory);
	_vala_array_add1 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, (SpitPluggable*) _tmp2_);
	_tmp3_ = slide_effect_descriptor_new (resource_directory);
	_vala_array_add2 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, (SpitPluggable*) _tmp3_);
	_tmp4_ = crumble_effect_descriptor_new (resource_directory);
	_vala_array_add3 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, (SpitPluggable*) _tmp4_);
	_tmp5_ = blinds_effect_descriptor_new (resource_directory);
	_vala_array_add4 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, (SpitPluggable*) _tmp5_);
	_tmp6_ = circle_effect_descriptor_new (resource_directory);
	_vala_array_add5 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, (SpitPluggable*) _tmp6_);
	_tmp7_ = circles_effect_descriptor_new (resource_directory);
	_vala_array_add6 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, (SpitPluggable*) _tmp7_);
	_tmp8_ = clock_effect_descriptor_new (resource_directory);
	_vala_array_add7 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, (SpitPluggable*) _tmp8_);
	_tmp9_ = squares_effect_descriptor_new (resource_directory);
	_vala_array_add8 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, (SpitPluggable*) _tmp9_);
	_tmp10_ = chess_effect_descriptor_new (resource_directory);
	_vala_array_add9 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, (SpitPluggable*) _tmp10_);
	_tmp11_ = stripes_effect_descriptor_new (resource_directory);
	_vala_array_add10 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, (SpitPluggable*) _tmp11_);
	_g_object_unref0 (resource_directory);
	return self;
}

ShotwellTransitions*
shotwell_transitions_new (GFile* module_file)
{
	return shotwell_transitions_construct (TYPE_SHOTWELL_TRANSITIONS, module_file);
}

static const gchar*
shotwell_transitions_real_get_module_name (SpitModule* base)
{
	ShotwellTransitions * self;
	const gchar* result;
	self = (ShotwellTransitions*) base;
	result = _ ("Core Slideshow Transitions");
	return result;
}

static const gchar*
shotwell_transitions_real_get_version (SpitModule* base)
{
	ShotwellTransitions * self;
	const gchar* result;
	self = (ShotwellTransitions*) base;
	result = _VERSION;
	return result;
}

static const gchar*
shotwell_transitions_real_get_id (SpitModule* base)
{
	ShotwellTransitions * self;
	const gchar* result;
	self = (ShotwellTransitions*) base;
	result = "io.elementary.photos.transitions";
	return result;
}

static SpitPluggable**
shotwell_transitions_real_get_pluggables (SpitModule* base,
                                          gint* result_length1)
{
	ShotwellTransitions * self;
	SpitPluggable** _tmp0_;
	gint _tmp0__length1;
	SpitPluggable** _tmp1_;
	gint _tmp1__length1;
	SpitPluggable** result;
	self = (ShotwellTransitions*) base;
	_tmp0_ = self->priv->pluggables;
	_tmp0__length1 = self->priv->pluggables_length1;
	_tmp1_ = _tmp0_;
	_tmp1__length1 = _tmp0__length1;
	if (result_length1) {
		*result_length1 = _tmp1__length1;
	}
	result = _tmp1_;
	return result;
}

static void
shotwell_transitions_class_init (ShotwellTransitionsClass * klass,
                                 gpointer klass_data)
{
	shotwell_transitions_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &ShotwellTransitions_private_offset);
	G_OBJECT_CLASS (klass)->finalize = shotwell_transitions_finalize;
}

static void
shotwell_transitions_spit_module_interface_init (SpitModuleIface * iface,
                                                 gpointer iface_data)
{
	shotwell_transitions_spit_module_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_module_name = (const gchar* (*) (SpitModule*)) shotwell_transitions_real_get_module_name;
	iface->get_version = (const gchar* (*) (SpitModule*)) shotwell_transitions_real_get_version;
	iface->get_id = (const gchar* (*) (SpitModule*)) shotwell_transitions_real_get_id;
	iface->get_pluggables = (SpitPluggable** (*) (SpitModule*, gint*)) shotwell_transitions_real_get_pluggables;
}

static void
shotwell_transitions_instance_init (ShotwellTransitions * self,
                                    gpointer klass)
{
	SpitPluggable** _tmp0_;
	self->priv = shotwell_transitions_get_instance_private (self);
	_tmp0_ = g_new0 (SpitPluggable*, 0 + 1);
	self->priv->pluggables = _tmp0_;
	self->priv->pluggables_length1 = 0;
	self->priv->_pluggables_size_ = self->priv->pluggables_length1;
}

static void
shotwell_transitions_finalize (GObject * obj)
{
	ShotwellTransitions * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SHOTWELL_TRANSITIONS, ShotwellTransitions);
	self->priv->pluggables = (_vala_array_free (self->priv->pluggables, self->priv->pluggables_length1, (GDestroyNotify) g_object_unref), NULL);
	G_OBJECT_CLASS (shotwell_transitions_parent_class)->finalize (obj);
}

static GType
shotwell_transitions_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ShotwellTransitionsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) shotwell_transitions_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ShotwellTransitions), 0, (GInstanceInitFunc) shotwell_transitions_instance_init, NULL };
	static const GInterfaceInfo spit_module_info = { (GInterfaceInitFunc) shotwell_transitions_spit_module_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType shotwell_transitions_type_id;
	shotwell_transitions_type_id = g_type_register_static (G_TYPE_OBJECT, "ShotwellTransitions", &g_define_type_info, 0);
	g_type_add_interface_static (shotwell_transitions_type_id, SPIT_TYPE_MODULE, &spit_module_info);
	ShotwellTransitions_private_offset = g_type_add_instance_private (shotwell_transitions_type_id, sizeof (ShotwellTransitionsPrivate));
	return shotwell_transitions_type_id;
}

GType
shotwell_transitions_get_type (void)
{
	static volatile gsize shotwell_transitions_type_id__once = 0;
	if (g_once_init_enter (&shotwell_transitions_type_id__once)) {
		GType shotwell_transitions_type_id;
		shotwell_transitions_type_id = shotwell_transitions_get_type_once ();
		g_once_init_leave (&shotwell_transitions_type_id__once, shotwell_transitions_type_id);
	}
	return shotwell_transitions_type_id__once;
}

SpitModule*
spit_entry_point (SpitEntryPointParams* params)
{
	ShotwellTransitions* _tmp0_ = NULL;
	ShotwellTransitions* _tmp3_;
	SpitModule* result;
	(*params).module_spit_interface = spit_negotiate_interfaces ((*params).host_min_spit_interface, (*params).host_max_spit_interface, SPIT_CURRENT_INTERFACE);
	if ((*params).module_spit_interface != SPIT_UNSUPPORTED_INTERFACE) {
		GFile* _tmp1_;
		ShotwellTransitions* _tmp2_;
		_tmp1_ = (*params).module_file;
		_tmp2_ = shotwell_transitions_new (_tmp1_);
		_g_object_unref0 (_tmp0_);
		_tmp0_ = _tmp2_;
	} else {
		_g_object_unref0 (_tmp0_);
		_tmp0_ = NULL;
	}
	_tmp3_ = _tmp0_;
	_tmp0_ = NULL;
	result = (SpitModule*) _tmp3_;
	_g_object_unref0 (_tmp0_);
	return result;
}

static inline gpointer
shotwell_transition_descriptor_get_instance_private (ShotwellTransitionDescriptor* self)
{
	return G_STRUCT_MEMBER_P (self, ShotwellTransitionDescriptor_private_offset);
}

ShotwellTransitionDescriptor*
shotwell_transition_descriptor_construct (GType object_type,
                                          GFile* resource_directory)
{
	ShotwellTransitionDescriptor * self = NULL;
	GThemedIcon* _tmp0_;
	g_return_val_if_fail (resource_directory != NULL, NULL);
	self = (ShotwellTransitionDescriptor*) g_object_new (object_type, NULL);
	_tmp0_ = (GThemedIcon*) g_themed_icon_new ("slideshow-plugin");
	_g_object_unref0 (self->priv->icon);
	self->priv->icon = (GIcon*) _tmp0_;
	return self;
}

static gint
shotwell_transition_descriptor_real_get_pluggable_interface (SpitPluggable* base,
                                                             gint min_host_interface,
                                                             gint max_host_interface)
{
	ShotwellTransitionDescriptor * self;
	gint result;
	self = (ShotwellTransitionDescriptor*) base;
	result = spit_negotiate_interfaces (min_host_interface, max_host_interface, SPIT_TRANSITIONS_CURRENT_INTERFACE);
	return result;
}

static const gchar*
shotwell_transition_descriptor_real_get_id (ShotwellTransitionDescriptor* self)
{
	g_critical ("Type `%s' does not implement abstract method `shotwell_transition_descriptor_get_id'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

const gchar*
shotwell_transition_descriptor_get_id (ShotwellTransitionDescriptor* self)
{
	ShotwellTransitionDescriptorClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = SHOTWELL_TRANSITION_DESCRIPTOR_GET_CLASS (self);
	if (_klass_->get_id) {
		return _klass_->get_id (self);
	}
	return NULL;
}

static const gchar*
shotwell_transition_descriptor_real_get_pluggable_name (ShotwellTransitionDescriptor* self)
{
	g_critical ("Type `%s' does not implement abstract method `shotwell_transition_descriptor_get_pluggable_name'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

const gchar*
shotwell_transition_descriptor_get_pluggable_name (ShotwellTransitionDescriptor* self)
{
	ShotwellTransitionDescriptorClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = SHOTWELL_TRANSITION_DESCRIPTOR_GET_CLASS (self);
	if (_klass_->get_pluggable_name) {
		return _klass_->get_pluggable_name (self);
	}
	return NULL;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
shotwell_transition_descriptor_real_get_info (SpitPluggable* base,
                                              SpitPluggableInfo* info)
{
	ShotwellTransitionDescriptor * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GIcon* _tmp7_;
	GIcon* _tmp8_;
	self = (ShotwellTransitionDescriptor*) base;
	g_return_if_fail (info != NULL);
	_tmp0_ = g_strdup ("Maxim Kartashev");
	_g_free0 ((*info).authors);
	(*info).authors = _tmp0_;
	_tmp1_ = g_strdup (_ ("Copyright 2010 Maxim Kartashev, Copyright 2011-2013 Yorba Foundation"));
	_g_free0 ((*info).copyright);
	(*info).copyright = _tmp1_;
	_tmp2_ = g_strdup (RESOURCES_TRANSLATORS);
	_g_free0 ((*info).translators);
	(*info).translators = _tmp2_;
	_tmp3_ = g_strdup (_VERSION);
	_g_free0 ((*info).version);
	(*info).version = _tmp3_;
	_tmp4_ = g_strdup (RESOURCES_WEBSITE_NAME);
	_g_free0 ((*info).website_name);
	(*info).website_name = _tmp4_;
	_tmp5_ = g_strdup (RESOURCES_WEBSITE_URL);
	_g_free0 ((*info).website_url);
	(*info).website_url = _tmp5_;
	(*info).is_license_wordwrapped = FALSE;
	_tmp6_ = g_strdup (RESOURCES_LICENSE);
	_g_free0 ((*info).license);
	(*info).license = _tmp6_;
	_tmp7_ = self->priv->icon;
	_tmp8_ = _g_object_ref0 (_tmp7_);
	_g_object_unref0 ((*info).icon);
	(*info).icon = _tmp8_;
}

static void
shotwell_transition_descriptor_real_activation (SpitPluggable* base,
                                                gboolean enabled)
{
	ShotwellTransitionDescriptor * self;
	self = (ShotwellTransitionDescriptor*) base;
}

static SpitTransitionsEffect*
shotwell_transition_descriptor_real_create (ShotwellTransitionDescriptor* self,
                                            SpitHostInterface* host)
{
	g_critical ("Type `%s' does not implement abstract method `shotwell_transition_descriptor_create'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

SpitTransitionsEffect*
shotwell_transition_descriptor_create (ShotwellTransitionDescriptor* self,
                                       SpitHostInterface* host)
{
	ShotwellTransitionDescriptorClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = SHOTWELL_TRANSITION_DESCRIPTOR_GET_CLASS (self);
	if (_klass_->create) {
		return _klass_->create (self, host);
	}
	return NULL;
}

static void
shotwell_transition_descriptor_class_init (ShotwellTransitionDescriptorClass * klass,
                                           gpointer klass_data)
{
	shotwell_transition_descriptor_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &ShotwellTransitionDescriptor_private_offset);
	((ShotwellTransitionDescriptorClass *) klass)->get_id = (const gchar* (*) (ShotwellTransitionDescriptor*)) shotwell_transition_descriptor_real_get_id;
	((ShotwellTransitionDescriptorClass *) klass)->get_pluggable_name = (const gchar* (*) (ShotwellTransitionDescriptor*)) shotwell_transition_descriptor_real_get_pluggable_name;
	((ShotwellTransitionDescriptorClass *) klass)->create = (SpitTransitionsEffect* (*) (ShotwellTransitionDescriptor*, SpitHostInterface*)) shotwell_transition_descriptor_real_create;
	G_OBJECT_CLASS (klass)->finalize = shotwell_transition_descriptor_finalize;
}

static void
shotwell_transition_descriptor_spit_pluggable_interface_init (SpitPluggableIface * iface,
                                                              gpointer iface_data)
{
	shotwell_transition_descriptor_spit_pluggable_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_pluggable_interface = (gint (*) (SpitPluggable*, gint, gint)) shotwell_transition_descriptor_real_get_pluggable_interface;
	iface->get_id = (const gchar* (*) (SpitPluggable*)) shotwell_transition_descriptor_get_id;
	iface->get_pluggable_name = (const gchar* (*) (SpitPluggable*)) shotwell_transition_descriptor_get_pluggable_name;
	iface->get_info = (void (*) (SpitPluggable*, SpitPluggableInfo*)) shotwell_transition_descriptor_real_get_info;
	iface->activation = (void (*) (SpitPluggable*, gboolean)) shotwell_transition_descriptor_real_activation;
}

static void
shotwell_transition_descriptor_spit_transitions_descriptor_interface_init (SpitTransitionsDescriptorIface * iface,
                                                                           gpointer iface_data)
{
	shotwell_transition_descriptor_spit_transitions_descriptor_parent_iface = g_type_interface_peek_parent (iface);
	iface->create = (SpitTransitionsEffect* (*) (SpitTransitionsDescriptor*, SpitHostInterface*)) shotwell_transition_descriptor_create;
}

static void
shotwell_transition_descriptor_instance_init (ShotwellTransitionDescriptor * self,
                                              gpointer klass)
{
	self->priv = shotwell_transition_descriptor_get_instance_private (self);
}

static void
shotwell_transition_descriptor_finalize (GObject * obj)
{
	ShotwellTransitionDescriptor * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, ShotwellTransitionDescriptor);
	_g_object_unref0 (self->priv->icon);
	G_OBJECT_CLASS (shotwell_transition_descriptor_parent_class)->finalize (obj);
}

static GType
shotwell_transition_descriptor_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ShotwellTransitionDescriptorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) shotwell_transition_descriptor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ShotwellTransitionDescriptor), 0, (GInstanceInitFunc) shotwell_transition_descriptor_instance_init, NULL };
	static const GInterfaceInfo spit_pluggable_info = { (GInterfaceInitFunc) shotwell_transition_descriptor_spit_pluggable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	static const GInterfaceInfo spit_transitions_descriptor_info = { (GInterfaceInitFunc) shotwell_transition_descriptor_spit_transitions_descriptor_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType shotwell_transition_descriptor_type_id;
	shotwell_transition_descriptor_type_id = g_type_register_static (G_TYPE_OBJECT, "ShotwellTransitionDescriptor", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
	g_type_add_interface_static (shotwell_transition_descriptor_type_id, SPIT_TYPE_PLUGGABLE, &spit_pluggable_info);
	g_type_add_interface_static (shotwell_transition_descriptor_type_id, SPIT_TRANSITIONS_TYPE_DESCRIPTOR, &spit_transitions_descriptor_info);
	ShotwellTransitionDescriptor_private_offset = g_type_add_instance_private (shotwell_transition_descriptor_type_id, sizeof (ShotwellTransitionDescriptorPrivate));
	return shotwell_transition_descriptor_type_id;
}

GType
shotwell_transition_descriptor_get_type (void)
{
	static volatile gsize shotwell_transition_descriptor_type_id__once = 0;
	if (g_once_init_enter (&shotwell_transition_descriptor_type_id__once)) {
		GType shotwell_transition_descriptor_type_id;
		shotwell_transition_descriptor_type_id = shotwell_transition_descriptor_get_type_once ();
		g_once_init_leave (&shotwell_transition_descriptor_type_id__once, shotwell_transition_descriptor_type_id);
	}
	return shotwell_transition_descriptor_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

